==> user_referral-2.0.1.tar.gz: user_referral/src/Plugin/ExtraField/Display/Referrer.php <==
<?php

namespace Drupal\user_referral\Plugin\ExtraField\Display;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\extra_field_plus\Plugin\ExtraFieldPlusDisplayFormattedBase;
use Drupal\user_referral\Entity\UserReferralType;
use Drupal\user\Entity\User;
use Drupal\user_referral\UserReferral;

/**
 * Example Node Label Extra field with formatted output.
 *
 * @ExtraFieldDisplay(
 *   id = "user_referrer",
 *   label = @Translation("Referrer"),
 *   bundles = {
 *     "user.*",
 *   },
 *   visible = false
 * )
 */
class Referrer extends ExtraFieldPlusDisplayFormattedBase {

  /**
   * {@inheritdoc}
   */
  public function getLabel() {
    $settings = $this->getSettings();
    return $settings['label'];
  }

  /**
   * {@inheritdoc}
   */
  public function getLabelDisplay() {
    $settings = $this->getSettings();
    return $settings['label_display'];
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(ContentEntityInterface $entity) {
    $settings = $this->getSettings();

    $element = [];

    if (\Drupal::currentUser()->hasPermission('view referrer of any user') && $referral_entry = UserReferral::getReferralEntry($entity)) {
      $referrer = User::load($referral_entry->referrer_uid);
      $referral_type = UserReferralType::load($referral_entry->type);
      if ($referrer && $referral_type) {
        $token_data = [
          'user' => $referrer,
          'user_referral_type' => $referral_type,
        ];
        $element = [
          '#markup' => \Drupal::token()->replace($settings['value'], $token_data),
        ];
      }
      
    }

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm() {
    $form = parent::settingsForm();

    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#required' => TRUE,
    ];

    $form['label_display'] = [
      '#type' => 'select',
      '#title' => $this->t('Label display'),
      '#options' => [
        'above' => $this->t('Above'),
        'inline' => $this->t('Inline'),
        'hidden' => $this->t('- Hidden -'),
        'visually_hidden' => $this->t('- Visually Hidden -'),
      ],
      '#required' => TRUE,
    ];

    $form['value'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Value'),
      '#required' => TRUE,
      '#description' => $this->t('Entere value with token to format the referrer value output.'),
    ];

    $token_types = ['user', 'user_referral_type'];
    $form['token_help'] = [
      '#theme' => 'token_tree_link',
      '#token_types' => $token_types,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultFormValues() {
    $values = parent::defaultFormValues();

    $plugin_definition = $this->getPluginDefinition();

    $values += [
      'label' => $plugin_definition['label'],
      'label_display' => 'hidden',
      'value' => '[user:name] ([user_referral_type:name])',
    ];

    return $values;
  }

}

==> user_referral-3.1.1.tar.gz: user_referral/src/Plugin/ExtraField/Display/Referrer.php <==
<?php

namespace Drupal\user_referral\Plugin\ExtraField\Display;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\extra_field_plus\Plugin\ExtraFieldPlusDisplayFormattedBase;
use Drupal\user_referral\Entity\UserReferralType;
use Drupal\user\Entity\User;
use Drupal\user_referral\UserReferral;

/**
 * Example Node Label Extra field with formatted output.
 *
 * @ExtraFieldDisplay(
 *   id = "user_referrer",
 *   label = @Translation("Referrer"),
 *   bundles = {
 *     "user.*",
 *   },
 *   visible = false
 * )
 */
class Referrer extends ExtraFieldPlusDisplayFormattedBase {

  /**
   * {@inheritdoc}
   */
  public function getLabel() {
    $settings = $this->getEntityExtraFieldSettings();
    return $settings['label'];
  }

  /**
   * {@inheritdoc}
   */
  public function getLabelDisplay() {
    $settings = $this->getEntityExtraFieldSettings();
    return $settings['label_display'];
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(ContentEntityInterface $entity) {
    $settings = $this->getEntityExtraFieldSettings();

    $element = [];

    if (\Drupal::currentUser()->hasPermission('view referrer of any user') && $referral_entry = UserReferral::getReferralEntry($entity)) {
      $referrer = User::load($referral_entry->referrer_uid);
      $referral_type = UserReferralType::load($referral_entry->type);
      if ($referrer && $referral_type) {
        $token_data = [
          'user' => $referrer,
          'user_referral_type' => $referral_type,
        ];
        $element = [
          '#markup' => \Drupal::token()->replace($settings['value'], $token_data),
        ];
      }
      
    }

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  protected static function extraFieldSettingsForm(): array {
    $form = parent::extraFieldSettingsForm();

    $form['label'] = [
      '#type' => 'textfield',
      '#title' => t('Label'),
      '#required' => TRUE,
    ];

    $form['label_display'] = [
      '#type' => 'select',
      '#title' => t('Label display'),
      '#options' => [
        'above' => t('Above'),
        'inline' => t('Inline'),
        'hidden' => t('- Hidden -'),
        'visually_hidden' => t('- Visually Hidden -'),
      ],
      '#required' => TRUE,
    ];

    $form['value'] = [
      '#type' => 'textfield',
      '#title' => t('Value'),
      '#required' => TRUE,
      '#description' => t('Entere value with token to format the referrer value output.'),
    ];

    $token_types = ['user', 'user_referral_type'];
    $form['token_help'] = [
      '#theme' => 'token_tree_link',
      '#token_types' => $token_types,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected static function defaultExtraFieldSettings(): array {
    $values = parent::defaultExtraFieldSettings();

    $values += [
      'label' => t('Referrer'),
      'label_display' => 'hidden',
      'value' => '[user:name] ([user_referral_type:name])',
    ];

    return $values;
  }

}
